@@ -98,7 +98,7 @@ def to_one(dest_class, type=RelationType.DIRECT,
             id = None if self.is_singleton() else self.id
             url = session._build_url(src_resource_path, id, dest_resource_type)
             json = response_json(session.get(url), 200)
-            return dest_class(json, session)
+            return dest_class(json, session) if json else None
 
         def fetch_relationship_include(self, use_included=False):
             if use_included:
